
* ------------------------------------------------------------------------------
* KCP Machine Learning Project
* Data preparation program: Malawi 2010 survey data
* ------------------------------------------------------------------------------

version 14
set more off

* set working directory
global savedata = "Q:\Projects\ML_povprediction\MWI_2010_04252017"
global inputdata = "Q:\DataLib\Malawi\MWI_2010_IHS-III\MWI_2010_IHS-III_v01_M\Data\Original"
global roster ind_b03 ind_b04 ind_b05a ind_b18 ind_b21 ind_b22 ind_b23 ind_b24
global geoid hid geo_urbrur geo_district ea_id
global educ ind_c05a ind_c05b ind_c06 ind_c07a ind_c08 ind_c09 ind_c11 ind_c12 ind_c13 ind_c14 ind_c16 ind_c18 ind_c20 ind_c21
global hlth ind_d13 ind_d17 ind_d18 ind_d22 ind_d31a ind_d30 ind_d31b ind_d31c ind_d38 ind_d42 ind_d43
global labr ind_e11 ind_e13 ind_e14 ind_e18 ind_e21 ind_e60
global housing hld_f01 hld_f06 hld_f07 hld_f08 hld_f09 hld_f10 hld_f11 hld_f12 hld_f19 hld_f29 hld_f31 hld_f34 hld_f36 hld_f40 hld_f41 hld_f42 hld_f43 hld_f44

* GEOGRAPHIC LOCATION INFORMATION
* ===============================
use "$inputdata\HH\HH_MOD_A_FILT.dta", clear
duplicates report case_id
assert r(unique_value)==r(N)

keep case_id reside hh_a01 ea_id

rename case_id hid
la var hid "Household ID"
rename hh_a01 geo_district
la var geo_district "District"

rename reside geo_urbrur
la var geo_urbrur "Area of residence (urban/rural)"

sort hid
tempfile id_geo
save `id_geo', replace


* INDIVIDUAL-LEVEL DATA
* =====================

use "$inputdata\HH\HH_MOD_B.dta", clear
duplicates report case_id id_code
assert r(unique_value)==r(N)

* rename household id
rename case_id hid
la var hid "Household ID"

* rename individual id
rename id_code iid
la var iid "Individual sequential number within household"

rename hh_* ind_*

keep hid iid $roster
order hid iid $roster

rename ind_b03 ind_sex
rename ind_b04 ind_relation
rename ind_b05a ind_age
rename ind_b18 ind_educfath
rename ind_b21 ind_educmoth
rename ind_b22 ind_language
rename ind_b23 ind_religion
rename ind_b24 ind_marital

sort hid iid
tempfile indv
save `indv', replace

* add education information
use "$inputdata\HH\HH_MOD_C.dta", clear
duplicates report case_id id_code
assert r(unique_value)==r(N)

rename hh_* ind_*

keep case_id id_code $educ
* rename household id
rename case_id hid
* rename individual id
rename id_code iid

sort hid iid
merge 1:1 hid iid using `indv'
tab _
drop if _==1
drop _

recode ind_c05a ind_c05b ind_c06 ind_c11 ind_c13 ind_c20 (2=0)
la def yn 1 "Yes" 0 "No"
la val ind_c05a ind_c05b ind_c06 ind_c11 ind_c13 ind_c20 yn

keep hid iid ind_sex ind_relation ind_age ind_educfath ind_educmoth ind_language ind_religion ind_marital $educ
order hid iid ind_sex ind_relation ind_age ind_educfath ind_educmoth ind_language ind_religion ind_marital $educ

gen ind_readwrite = (ind_c05a==1 | ind_c05b==1), after(ind_marital) 
la var ind_readwrite "Can read and write (in English or Chichewa)"
la val ind_readwrite yn

rename ind_c05a ind_rwchichewa
rename ind_c05b ind_rwenglish
rename ind_c06 ind_educ01
rename ind_c07a ind_educ02
rename ind_c08 ind_educ03
rename ind_c09 ind_educ04
rename ind_c11 ind_educ05
rename ind_c12 ind_educ06
rename ind_c13 ind_educ07
rename ind_c14 ind_educ08
rename ind_c16 ind_educ09
rename ind_c18 ind_educ10
rename ind_c20 ind_educ11
rename ind_c21 ind_educ12

sort hid iid
save `indv', replace

* add health information to individual level file 
use "$inputdata\HH\HH_MOD_D.dta", clear
duplicates report case_id id_code
assert r(unique_value)==r(N)

rename hh_* ind_*
keep case_id id_code $hlth
* rename household id
rename case_id hid
* rename individual id
rename id_code iid

rename ind_d13 ind_health1
rename ind_d17 ind_health2
rename ind_d18 ind_health3
rename ind_d22 ind_health4
rename ind_d30 ind_health5
rename ind_d31a ind_health6
rename ind_d31b ind_health7
rename ind_d31c ind_health8
rename ind_d38 ind_breakfast
rename ind_d42 ind_birthplace
rename ind_d43 ind_birthattend 

recode ind_health1 ind_health2 ind_health3 ind_health4 ind_health5 (2=0)
la val ind_health1 ind_health2 ind_health3 ind_health4 ind_health5 yn
sort hid iid
tempfile hlt
save `hlt', replace

use `indv'
sort hid iid
merge 1:1 hid iid using `hlt'
tab _
drop if _==1
drop _
sort hid iid
save `indv', replace

* add employment information to individual level file
use "$inputdata\HH\HH_MOD_E.dta", clear
duplicates report case_id id_code
assert r(unique_value)==r(N)

rename hh_* ind_*
keep case_id id_code $labr
* rename household id
rename case_id hid
* rename individual id
rename id_code iid

recode ind_e13 ind_e14 ind_e18 ind_e60 (2=0)
la val ind_e13 ind_e14 ind_e18 ind_e60 yn

rename ind_e11 ind_work1
rename ind_e13 ind_work2
rename ind_e14 ind_work3
rename ind_e18 ind_work4
rename ind_e21 ind_work5
rename ind_e60 ind_work6

sort hid iid
tempfile emp
save `emp', replace

use `indv'
sort hid iid
merge 1:1 hid iid using `emp'
tab _
drop if _==1
drop _

compress
sort hid iid
save "$savedata\MWI_2012_individual", replace
********************************************************************************

* HOUSEHOLD-LEVEL DATA
* ====================
* housing 
use "$inputdata\HH\HH_MOD_F.dta", clear
duplicates report case_id
assert r(unique_value)==r(N) 

rename hh_* hld_*
keep case_id $housing

rename case_id hid
*rename hhsize der_hhsize

sort hid
merge 1:1 hid using `id_geo'
tab _
drop _

recode hld_f19 hld_f31 hld_f44 (2=0) //hh_f44 has one out of range value (4) 
la val hld_f19 hld_f31 hld_f44 yn

rename hld_f01 hld_dwelloccu
rename hld_f06 hld_dwelltype
rename hld_f07 hld_walls
rename hld_f08 hld_roof
rename hld_f09 hld_floor
rename hld_f10 hld_rooms
rename hld_f11 hld_lighting
rename hld_f12 hld_cooking
rename hld_f19 hld_electricity
rename hld_f29 hld_whynoelec
rename hld_f31 hld_mtltel
rename hld_f34 hld_nbcellpho
rename hld_f36 hld_dwater
rename hld_f40 hld_dwateros
rename hld_f41 hld_toilet
rename hld_f42 hld_toiletshr
rename hld_f43 hld_rubbish
rename hld_f44 hld_bednet

sort hid
save "$savedata\MWI_2012_household", replace

* add consumption data
use "$inputdata\HH\HH_MOD_G3.dta", clear
keep case_id hh_g09
collapse (max) hh_g09, by( case_id)
la var hh_g09 "Past 7 days, any people not listed as HH memebr eat any meal in your HH"

rename case_id hid
rename hh_g09 hld_g09

rename hld_g09 hld_nbguests

recode hld_nbguests (2=0)
la val hld_nbguests yn

sort hid
tempfile consd
save `consd', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `consd'
tab _
drop if _==2
drop _

sort hid
save "$savedata\MWI_2012_household", replace

* food consumption
use "$inputdata\HH\HH_MOD_G1.dta", clear

tab hh_g01, m
recode hh_g03a (0=.)(-3=.)
bys hh_g01: summ hh_g03a
replace hh_g01 =1 if hh_g03a <. 
replace hh_g01 =2 if hh_g03a >=.

keep if hh_g01 ==1
gen consume =1
keep case_id hh_g02 consume
duplicates report case_id hh_g02 consume
duplicates drop case_id hh_g02 consume, force

rename case_id hid
rename hh_g02 hld_g02

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide consume, i(hid) j(hld_g02)

sort hid
tempfile consd
save `consd', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `consd'
tab _
drop if _==2
drop _
sort hid
save "$savedata\MWI_2012_household", replace

* non-food consumption
* weekly
use "$inputdata\HH\HH_MOD_I1.dta", clear

tab hh_i01, m
bys hh_i01: summ hh_i03
replace hh_i01 =1 if hh_i03 <. 
replace hh_i01 =2 if hh_i03 >=.

keep if hh_i01 ==1
gen consume =1

replace hh_i02 = 1000 + hh_i02 
keep case_id hh_i02 consume
duplicates report case_id hh_i02 consume

rename case_id hid
rename hh_i02 hld_i02

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide consume, i(hid) j(hld_i02)

sort hid
tempfile consd
save `consd', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `consd'
tab _
drop if _==2
drop _
sort hid
save "$savedata\MWI_2012_household", replace

* monthly
use "$inputdata\HH\HH_MOD_I2.dta", clear
duplicates report case_id hh_i05
assert r(unique_value)==r(N)

tab hh_i04, m
recode hh_i06 (0=.)
bys hh_i04: summ hh_i06
replace hh_i04 =1 if hh_i06 <. 
replace hh_i04 =2 if hh_i06 >=.

keep if hh_i04 ==1
gen consume =1

replace hh_i05 = 1000 + hh_i05 
keep case_id hh_i05 consume
duplicates report case_id hh_i05 consume

rename case_id hid
rename hh_i05 hld_i05

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide consume, i(hid) j(hld_i05)

sort hid
tempfile consd
save `consd', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `consd'
tab _
drop if _==2
drop _
sort hid
save "$savedata\MWI_2012_household", replace

* three months
use "$inputdata\HH\HH_MOD_J.dta", clear
duplicates report case_id hh_j02
assert r(unique_value)==r(N)

tab hh_j01, m
recode hh_j03 (0=.)
bys hh_j01: summ hh_j03
replace hh_j01 =1 if hh_j03 <. 
replace hh_j01 =2 if hh_j03 >=.

keep if hh_j01 ==1
gen consume =1

replace hh_j02= 1000 + hh_j02 
keep case_id hh_j02 consume

rename case_id hid
rename hh_j02 hld_j02

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide consume, i(hid) j(hld_j02)

sort hid
tempfile consd
save `consd', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `consd'
tab _
drop if _==2
drop _
sort hid
save "$savedata\MWI_2012_household", replace

* 12 months
use "$inputdata\HH\HH_MOD_K.dta", clear
duplicates report case_id hh_k02
assert r(unique_value)==r(N)

tab hh_k01, m
recode hh_k03 hh_k04 (0=.)
bys hh_k01: summ hh_k03
bys hh_k01: summ hh_k04
replace hh_k01 =1 if hh_k03 <. | hh_k03 <.
replace hh_k01 =2 if hh_k03 >=. & hh_k04 >=.

keep if hh_k01 ==1
gen consume =1

replace hh_k02= 1000 + hh_k02 
keep case_id hh_k02 consume

rename case_id hid
rename hh_k02 hld_k02

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide consume, i(hid) j(hld_k02)

sort hid
tempfile consd
save `consd', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `consd'
tab _
drop if _==2
drop _
sort hid
save "$savedata\MWI_2012_household", replace

* durable goods
use "$inputdata\HH\HH_MOD_L.dta", clear
duplicates report case_id hh_l02
assert r(unique_value)==r(N)

tab hh_l01, m
recode hh_l03 (0=.)
bys hh_l01: summ hh_l03
replace hh_l01 =1 if hh_l03 <. 
replace hh_l01 =2 if hh_l03 >=.

keep if hh_l01 ==1
gen consume =1

replace hh_l02= 1000 + hh_l02 
keep case_id hh_l02 consume

rename case_id hid
rename hh_l02 hld_l02

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide consume, i(hid) j(hld_l02)

sort hid
tempfile consd
save `consd', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `consd'
tab _
drop if _==2
drop _
sort hid

rename consume??? cons_0???
rename consume???? cons_????

forvalues i=501(1)532 {
	rename cons_1`i' own_`i'
}	


* label consumption expenditure variables
*la var cons_100 "Cereals, Grains and Cereal Products"
la var cons_0101 "Maize ufa mgaiwa (normal flour)"
la var cons_0102 "Maize ufa refined (fine flour)"
la var cons_0103 "Maize ufa madeya (bran flour)"
la var cons_0104 "Maize grain (not as ufa)"
la var cons_0105 "Green maize"
la var cons_0106 "Rice"
la var cons_0107 "Finger millet (mawere)"
la var cons_0108 "Sorghum (mapira)"
la var cons_0109 "Pearl millet (mchewere)"
la var cons_0110 "Wheat flour"
la var cons_0111 "Bread"
la var cons_0112 "Buns, scones"
la var cons_0113 "Biscuits"
la var cons_0114 "Spaghetti, macaroni, pasta"
la var cons_0115 "Breakfast cereal"
la var cons_0116 "Infant feeding cereals"
la var cons_0117 "Other (specify)"
*la var cons_200 "Roots, Tubers, and Plantains"
la var cons_0201 "Cassava tubers"
la var cons_0202 "Cassava flour"
la var cons_0203 "White sweet potato"
la var cons_0204 "Orange sweet potato"
la var cons_0205 "Irish potato"
la var cons_0206 "Potato crisps"
la var cons_0207 "Plantain, cooking banana"
la var cons_0208 "Cocoyam (masimbi)"
la var cons_0209 "Other (specify)"
*a var consume300 "Nuts and Pulses"
la var cons_0301 "Bean, white"
la var cons_0302 "Bean, brown"
la var cons_0303 "Pigeonpea (nandolo)"
la var cons_0304 "Groundnut"
la var cons_0305 "Groundnut flour"
la var cons_0306 "Soyabean flour"
la var cons_0307 "Ground bean (nzama)"
la var cons_0308 "Cowpea (khobwe)"
la var cons_0309 "Macademia nuts"
la var cons_0310 "Other (specify)"
*la var cons_400 "Vegetables"
la var cons_0401 "Onion"
la var cons_0402 "Cabbage"
la var cons_0403 "Tanaposi/Rape"
la var cons_0404 "Nkhwani"
la var cons_0405 "Chinese cabbage"
la var cons_0406 "Other cultivated green leafy vegetables"
la var cons_0407 "Gathered wild green leaves"
la var cons_0408 "Tomato"
la var cons_0409 "Cucumber"
la var cons_0410 "Pumpkin"
la var cons_0411 "Okra / Therere"
la var cons_0412 "Tinned vegetables (Specify)"
la var cons_0413 "Mushroom"
la var cons_0414 "Other vegetables (Specify)"
*la var cons_500 "Meat, Fish and Animal products"
la var cons_0501 "Eggs"
la var cons_0502 "Dried fish"
la var cons_0503 "Fresh fish"
la var cons_0504 "Beef"
la var cons_0505 "Goat"
la var cons_0506 "Pork"
la var cons_0507 "Mutton"
la var cons_0508 "Chicken"
la var cons_0509 "Other poultry - guinea fowl, doves, etc."
la var cons_0510 "Small animal - rabbit, mice, etc."
la var cons_0511 "Termites, other insects (eg Ngumbi, caterpillar)"
la var cons_0512 "Tinned meat or fish"
la var cons_0513 "Smoked fish"
la var cons_0514 "Fish Soup/Sauce"
la var cons_0515 "Other (specify)"
*la var cons_600 "Fruits"
la var cons_0601 "Mango"
la var cons_0602 "Banana"
la var cons_0603 "Citrus - naartje, orange, etc."
la var cons_0604 "Pineapple"
la var cons_0605 "Papaya"
la var cons_0606 "Guava"
la var cons_0607 "Avocado"
la var cons_0608 "Wild fruit (masau, malambe, etc.)"
la var cons_0609 "Apple"
la var cons_0610 "Other fruits (specify)"
*la var cons_700 "Milk and Milk Products"
la var cons_0701 "Fresh milk"
la var cons_0702 "Powdered milk"
la var cons_0703 "Margarine - Blue band"
la var cons_0704 "Butter"
la var cons_0705 "Chambiko - soured milk"
la var cons_0706 "Yoghurt"
la var cons_0707 "Cheese"
la var cons_0708 "Infant feeding formula (for bottle)"
la var cons_0709 "Other (specify)"
*la var cons_800 "Sugar, Fats, and Oil"
la var cons_0801 "Sugar"
la var cons_0802 "Sugar Cane"
la var cons_0803 "Cooking oil"
la var cons_0804 "Other (specify)"
*la var cons_809 "Spices & Miscellaneous"
la var cons_0810 "Salt"
la var cons_0811 "Spices"
la var cons_0812 "Yeast, baking powder, bicarbonate of soda"
la var cons_0813 "Tomato sauce (bottle)"
la var cons_0814 "Hot sauce (Nali, etc.)"
la var cons_0815 "Jam, jelly"
la var cons_0816 "Sweets, candy, chocolates"
la var cons_0817 "Honey"
la var cons_0818 "Other (specify)"
*la var cons_819 "Cooked Foods from Vendors"
la var cons_0820 "Maize - boiled or roasted (vendor)"
la var cons_0821 "Chips (vendor)"
la var cons_0822 "Cassava - boiled (vendor)"
la var cons_0823 "Eggs - boiled (vendor)"
la var cons_0824 "Chicken (vendor)"
la var cons_0825 "Meat (vendor)"
la var cons_0826 "Fish (vendor)"
la var cons_0827 "Mandazi, doughnut (vendor)"
la var cons_0828 "Samosa (vendor)"
la var cons_0829 "Meal eaten at restaurant"
la var cons_0830 "Other (specify)"
*la var cons_900 "Beverages"
la var cons_0901 "Tea"
la var cons_0902 "Coffee"
la var cons_0903 "Cocoa, millo"
la var cons_0904 "Squash (Sobo drink concentrate)"
la var cons_0905 "Fruit juice"
la var cons_0906 "Freezes (flavoured ice)"
la var cons_0907 "Soft drinks (Coca-cola, Fanta, Sprite, etc.)"
la var cons_0908 "Chibuku (commercial traditional-style beer)"
la var cons_0909 "Bottled water"
la var cons_0910 "Maheu"
la var cons_0911 "Bottled / canned beer (Carlsberg, etc.)"
la var cons_0912 "Thobwa"
la var cons_0913 "Traditional beer (masese)"
la var cons_0914 "Wine or commercial liquor"
la var cons_0915 "Locally brewed liquor (kachasu)"
la var cons_0916 "Other (specify)"
la var cons_1101 "Charcoal"
la var cons_1102 "Paraffin or kerosene"
la var cons_1103 "Cigarettes or other tobacco"
la var cons_1104 "Candles"
la var cons_1105 "Matches"
la var cons_1106 "Newspapers or magazines"
la var cons_1107 "Public transport - Bicycle Taxi"
la var cons_1108 "Public transport - Bus/Minibus"
la var cons_1109 "Public transport - Other (Truck, Oxcart, Etc..)"
la var cons_1201 "Milling fees, grain"
la var cons_1202 "Bar soap (body soap or clothes soap)"
la var cons_1203 "Clothes soap (powder)"
la var cons_1204 "Toothpaste, toothbrush"
la var cons_1205 "Toilet paper"
la var cons_1206 "Glycerine, Vaseline, skin creams"
la var cons_1207 "Other personal products (shampoo, razor blades, cosmetics, hair products, etc.)"
la var cons_1209 "Light bulbs"
la var cons_1210 "Postage stamps or other postal fees"
la var cons_1211 "Donation - to church, charity, beggar, etc."
la var cons_1212 "Petrol or diesel"
la var cons_1213 "Motor vehicle service, repair, or parts"
la var cons_1214 "Bicycle service, repair, or parts"
la var cons_1215 "Wages paid to servants"
la var cons_1216 "Mortgage - regular payment to purchase house"
la var cons_1217 "Repairs & maintenance to dwelling"
la var cons_1218 "Repairs to household and personal items (radios, watches, etc., excluding battery purchases)"
la var cons_1219 "Expenditures on pets"
la var cons_1220 "Batteries"
la var cons_1221 "Recharging batteries, cell phones"
la var cons_1301 "Infant clothing"
la var cons_1302 "Baby nappies/diapers"
la var cons_1303 "Boy's trousers"
la var cons_1304 "Boy's shirts"
la var cons_1305 "Boy's jackets"
la var cons_1306 "Boy's undergarments"
la var cons_1307 "Boy's other clothing"
la var cons_1308 "Men's trousers"
la var cons_1309 "Men's shirts"
la var cons_1310 "Men's jackets"
la var cons_1311 "Men's undergarments"
la var cons_1312 "Men's other clothing"
la var cons_1313 "Girl's blouse/shirt"
la var cons_1314 "Girl's dress/skirt"
la var cons_1315 "Girl's undergarments"
la var cons_1316 "Girl's other clothing"
la var cons_1317 "Lady's blouse/shirt"
la var cons_1318 "Chitenje cloth"
la var cons_1319 "Lady's dress/skirt"
la var cons_1320 "Lady's undergarments"
la var cons_1321 "Lady's other clothing"
la var cons_1322 "Boy's shoes"
la var cons_1323 "Men's shoes"
la var cons_1324 "Girl's shoes"
la var cons_1325 "Lady's shoes"
la var cons_1326 "Cloth, thread, other sewing material"
la var cons_1327 "Laundry, dry cleaning, tailoring fees"
la var cons_1328 "Bowls, glassware, plates, silverware, etc."
la var cons_1329 "Cooking utensils (cookpots, stirring spoons and wisks, etc.)"
la var cons_1330 "Cleaning utensils (brooms, brushes, etc.)"
la var cons_1331 "Torch / flashlight"
la var cons_1332 "Umbrella"
la var cons_1333 "Paraffin lamp (hurricane or pressure)"
la var cons_1334 "Stationery items (not for school)"
la var cons_1335 "Books (not for school)"
la var cons_1336 "Music or video cassette or CD/DVD"
la var cons_1337 "Tickets for sports / entertainment events"
la var cons_1338 "House decorations"
la var cons_1339 "Night's lodging in rest house or hotel"
la var cons_1401 "Carpet, rugs, drapes, curtains"
la var cons_1402 "Linen - towels, sheets, blankets"
la var cons_1403 "Mat - sleeping or for drying maize flour"
la var cons_1404 "Mosquito net"
la var cons_1405 "Mattress"
la var cons_1406 "Sports & hobby equipment, musical instruments, toys"
la var cons_1407 "Film, film processing, camera"
la var cons_1408 "Cement"
la var cons_1409 "Bricks"
la var cons_1410 "Construction timber"
la var cons_1411 "Council rates"
la var cons_1412 "Insurance - health (MASM, etc.), auto, home, life"
la var cons_1413 "Losses to theft (value of items or cash lost)"
la var cons_1414 "Fines or legal fees"
la var cons_1415 "Lobola (bridewealth) costs"
la var cons_1416 "Marriage ceremony costs"
la var cons_1417 "Funeral costs, household members"
la var cons_1418 "Funeral costs, nonhousehold members (relatives, neighbors/friends)"
la var cons_1419 "Woodpoles, bamboo"
la var cons_1420 "Grass for thatching roof or other use"
la var own_501 "Mortar/pestle (mtondo)"
la var own_502 "Bed"
la var own_503 "Table"
la var own_504 "Chair"
la var own_505 "Fan"
la var own_506 "Air conditioner"
la var own_507 "Radio ('wireless')"
la var own_508 "Tape or CD/DVD player; HiFi"
la var own_509 "Television"
la var own_510 "VCR"
la var own_511 "Sewing machine"
la var own_512 "Kerosene/paraffin stove"
la var own_513 "Electric or gas stove; hot plate"
la var own_514 "Refrigerator"
la var own_515 "Washing machine"
la var own_516 "Bicycle"
la var own_517 "Motorcycle/scooter"
la var own_518 "Car"
la var own_519 "Mini-bus"
la var own_520 "Lorry"
la var own_521 "Beer-brewing drum"
la var own_522 "Upholstered chair, sofa set"
la var own_523 "Coffee table (for sitting room)"
la var own_524 "Cupboard, drawers, bureau"
la var own_525 "Lantern (paraffin)"
la var own_526 "Desk"
la var own_527 "Clock"
la var own_528 "Iron (for pressing clothes)"
la var own_529 "Computer equipment & accessories"
la var own_530 "Sattelite dish"
la var own_531 "Solar panel"
la var own_532 "Generator"

recode cons_* own_* (.=0)
la def yn 0 "No" 1 "Yes"
la val cons_* own_* yn

sort hid
save "$savedata\MWI_2012_household", replace
********************************************************************************
* Food security
use "$inputdata\HH\HH_MOD_H.dta", clear
duplicates report case_id

keep case_id hh_h01

rename case_id hid
rename hh_h01 hld_foodsecurity

recode hld_foodsecurity (2=0)
la val hld_foodsecurity yn
sort hid
tempfile foods
save `foods', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `foods'
tab _
drop if _==2
drop _

sort hid
save "$savedata\MWI_2012_household", replace

**** Farm **********************************************************************
* ownership of farm implements, machinery and structures
use "$inputdata\HH\HH_MOD_M.dta", clear
drop if hh_m0a==.

tab hh_m0c, m
recode hh_m01 (0=.)
bys hh_m0c: summ hh_m01
replace hh_m0c =1 if hh_m01 <. 
replace hh_m0c =2 if hh_m01 >=. 

duplicates report case_id hh_m0a
* there are four duplicate cases
duplicates drop case_id hh_m0a, force

keep if hh_m0c ==1
gen farm_ =1

keep case_id hh_m0a farm

rename case_id hid
rename hh_m0a hld_m0a

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide farm_, i(hid) j(hld_m0a)

la var farm_601 "Hand hoe"
la var farm_602 "Slasher"
la var farm_603 "Axe"
la var farm_604 "Sprayer"
la var farm_605 "Panga knife"
la var farm_606 "Sickle"
la var farm_607 "Treadle pump"
la var farm_608 "Watering can"
la var farm_609 "Ox cart"
la var farm_610 "Ox plough"
la var farm_611 "Tractor"
la var farm_612 "Tractor plough"
la var farm_613 "Ridger"
la var farm_614 "Cultivator"
la var farm_615 "Generator"
la var farm_616 "Motorized pump"
la var farm_617 "Grain mill"
la var farm_618 "Other (specify)"
la var farm_619 "Chicken house"
la var farm_620 "Livestock kraal"
la var farm_621 "Poultry kraal"
la var farm_622 "Storage house"
la var farm_623 "Granary"
la var farm_624 "Barn"
la var farm_625 "Pig sty"

recode farm_* (.=0)
la val farm_* yn
sort hid
tempfile farm
save `farm', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `farm'
tab _
drop if _==2
drop _

sort hid
save "$savedata\MWI_2012_household", replace

**** Enterprises ***************************************************************

use "$inputdata\HH\HH_MOD_N1.dta", clear
duplicates report case_id
assert r(unique_value)==r(N)

keep case_id hh_n0a hh_n01 hh_n02 hh_n03 hh_n04 hh_n05 hh_n06 hh_n07 hh_n08
recode hh_n0a hh_n01 hh_n02 hh_n03 hh_n04 hh_n05 hh_n06 hh_n07 hh_n08 (2=0)
la val hh_n0a hh_n01 hh_n02 hh_n03 hh_n04 hh_n05 hh_n06 hh_n07 hh_n08 yn

rename case_id hid
rename hh_n0a hld_busin1
rename hh_n01 hld_busin2
rename hh_n02 hld_busin3
rename hh_n03 hld_busin4
rename hh_n04 hld_busin5
rename hh_n05 hld_busin6
rename hh_n06 hld_busin7
rename hh_n07 hld_busin8
rename hh_n08 hld_busin9

sort hid
tempfile entrp
save `entrp', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `entrp'
tab _
drop if _==2
drop _

sort hid
save "$savedata\MWI_2012_household", replace

**** other income **************************************************************
use "$inputdata\HH\HH_MOD_P.dta", clear
duplicates report case_id hh_p0a
assert r(unique_value)==r(N)

drop if hh_p0a ==.

tab hh_p01, m
egen totothin = rowtotal( hh_p02 hh_p03a hh_p03b hh_p03c)
recode totothin (0=.)
bys hh_p01: summ totothin
replace hh_p01 =2 if hh_p01 ==.

keep if hh_p01 ==1
gen inc_ =1

keep case_id hh_p0a inc_
rename case_id hid
rename hh_p0a hld_p0a

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide inc_, i(hid) j(hld_p0a)

la var inc_101 "Cash Transfers/Gifts from individuals"
la var inc_102 "Food Transfers/Gifts from Individuals"
la var inc_103 "Non-Food In-Kind Transfers/Gifts form Individuals"
la var inc_104 "Savings, Interest or Other Investment Income"
la var inc_105 "Pension Income"
la var inc_106 "Income from Non-Agricultural Land Rental"
la var inc_107 "Income form Apartment, House Rental"
la var inc_108 "Income from Sho, Store Rental"
la var inc_109 "Income from Car, Truck, Other Vehicle Rental"
la var inc_110 "Income from Real Estate Sales"
la var inc_111 "Income from Household Non-Agricultural Asset Sales"
la var inc_112 "Income from Household Agricultural/Fishing Asset Sales"
la var inc_113 "Inheritance"
la var inc_114 "Lottery/Gambling Winnings"
la var inc_115 "Other Income (Specify)"

recode inc_* (.=0)
la val inc_* yn

sort hid
tempfile otinc
save `otinc', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `otinc'
tab _
drop if _==2
drop _

sort hid
save "$savedata\MWI_2012_household", replace

**** gifts given out ************************************************************
use "$inputdata\HH\HH_MOD_Q.dta", clear
duplicates report case_id hh_q0a
assert r(unique_value)==r(N)

tab hh_q01, m
egen totgifts = rowtotal(hh_q02a hh_q02b hh_q02c)
recode totgifts (0=.)
bys hh_q01: summ totgifts
replace hh_q01 =2 if hh_q01 ==.

keep if hh_q01 ==1
gen gifts =1

keep case_id hh_q0a gifts
rename case_id hid
rename hh_q0a hld_q0a

* reshape the dataset to wide format (equivalent to converting item level data into household level file)
reshape wide gifts, i(hid) j(hld_q0a)

*la var gifts200 "Outgoing Transfers/Gifts"
la var gifts201 "Cash Transfers/Gifts"
la var gifts202 "Food Transfers/Gifts"
la var gifts203 "Non-Food In-Kind Transfers/Gifts"

recode gifts* (.=0)
la val gifts* yesno

sort hid
tempfile gft
save `gft', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `gft'
tab _
drop if _==2
drop _

sort hid
save "$savedata\MWI_2012_household", replace

**** credit *********************************************************************
use "$inputdata\HH\HH_MOD_S2.dta", clear
duplicates report case_id
assert r(unique_value)==r(N)

keep case_id hh_s12 hh_s14
recode hh_s12 (2=0)
la val hh_s12 yn

rename case_id hid
rename hh_s12 hld_credit1
rename hh_s14 hld_credit2

sort hid
tempfile credit
save `credit', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `credit'
tab _
drop if _==2
drop _

sort hid
save "$savedata\MWI_2012_household", replace

**** subjective well-being ******************************************************
use "$inputdata\HH\HH_MOD_T.dta", clear
duplicates report case_id
assert r(unique_value)==r(N)

keep case_id hh_t01 hh_t02 hh_t03 hh_t04 hh_t05 hh_t08 hh_t10

rename case_id hid
rename hh_t01 hld_adeqfood
rename hh_t02 hld_adeqhous
rename hh_t03 hld_adeqcloth
rename hh_t04 hld_adeqhealth
rename hh_t05 hld_selfscale
rename hh_t08 hld_selfincome
rename hh_t10 hld_headsleep

sort hid
tempfile wellb
save `wellb', replace

use "$savedata\MWI_2012_household", clear
merge 1:1 hid using `wellb'
tab _
drop if _==2
drop _

sort hid
save "$savedata\MWI_2012_household", replace
********************************************************************************

** COMMUNITY LEVEL DATA 
* =====================

* community identification information
use "$inputdata\Community\COM_CA.dta", clear
duplicates report ea_id
assert r(unique_value)==r(N)

global comid ea_id 

keep ea_id 
sort ea_id

tempfile combasic
save `combasic' , replace

* access to basic services
use "$inputdata\Community\COM_CD.dta", clear
duplicates report ea_id
assert r(unique_value)==r(N)

keep ea_id com_cd01 com_cd03 com_cd06 com_cd12 com_cd15 com_cd17 com_cd21 com_cd23 ///
com_cd27a com_cd27b com_cd30 com_cd35 com_cd48 com_cd50 com_cd51a com_cd51b com_cd66

* summarized distance to the primary school
bys com_cd27b: summ com_cd27a

* convert distance into kilometer
gen com_cd27 = com_cd27a if com_cd27b ==2 // kilometer
replace com_cd27 = com_cd27a/1000 if com_cd27b ==1 // meter into kilometer
replace com_cd27 = com_cd27a * 1.60934 if com_cd27b ==3 // meter into kilometer

summ com_cd27

* recode distance (1 - In the community, 2 - Between 0 to 2 kilometer, 3 - 3 to 5 kilometers, 4 - Above 5 kilometers)
gen com_cd27r = 1 if com_cd27 ==0
la var com_cd27r "Distance to nearest government primary school"
replace com_cd27r =2 if com_cd27 > 0 & com_cd27 < 3
replace com_cd27r =3 if com_cd27 >= 3 & com_cd27 < 5
replace com_cd27r =4 if com_cd27 >= 5 & com_cd27 ~=.

la def com_cd27 1 "In the community" 2 "Under 2 kilometers"  3 "3 to 5 kilometers" 4 "5 and above kilometers"
la val com_cd27r com_cd27

* summarized distance to nearest health clinic
bys com_cd51b: summ com_cd51a

* convert distance into kilometer
gen com_cd51 = com_cd51a if com_cd51b ==2 // kilometer
replace com_cd51 = com_cd51a/1000 if com_cd51b ==1 // meter into kilometer
replace com_cd51 = com_cd51a * 1.60934 if com_cd51b ==3 // meter into kilometer

summ com_cd51, detail
* recode distance (1 - 0 to 5, 2 - 6 to 10, 3 - 11 to 15, 4 - 16 to 20, 5 - 21 to 25, 6 - 26 to 30,  7 - Above 30 kilometers
gen com_cd51r = 1 if com_cd51 >= 0 & com_cd51 <= 5
la var com_cd51r "Distance to nearest health clinic"
replace com_cd51r =2 if com_cd51 >= 6 & com_cd51 <= 10
replace com_cd51r =3 if com_cd51 >= 11 & com_cd51 <= 15
replace com_cd51r =4 if com_cd51 >= 16 & com_cd51 <= 20
replace com_cd51r =5 if com_cd51 >= 21 & com_cd51 <= 25
replace com_cd51r =6 if com_cd51 >= 26 & com_cd51 <= 30
replace com_cd51r =7 if com_cd51 > 30 & com_cd51 ~=.

la def com_cd51 1 "0 to 5 kilometes" 2 "6 to 10 kilometers" 3 "11 to 15 kilometers" ///
		4 "16 to 20 kilometers" 5 "21 to 25 kilometers" 6 "26 to 30 kilometers" 7 "Above 30 kilometers"

la val com_cd51r com_cd51
keep ea_id com_cd01 com_cd03 com_cd06 com_cd12 com_cd15 com_cd17 com_cd21 com_cd23 ///
com_cd27r com_cd30 com_cd35 com_cd48 com_cd50 com_cd51r com_cd66

order ea_id com_cd01 com_cd03 com_cd06 com_cd12 com_cd15 com_cd17 com_cd21 com_cd23 ///
com_cd27r com_cd30 com_cd35 com_cd48 com_cd50 com_cd51r com_cd66

sort ea_id
merge 1:1 ea_id using `combasic'
tab _
drop if _==1
drop _

recode com_cd06 com_cd12 com_cd15 com_cd17 com_cd21 com_cd30 com_cd35 com_cd48 com_cd50 com_cd66 (2=0)
la def yesno 1 "Yes" 0 "No"
la val com_cd06 com_cd12 com_cd15 com_cd17 com_cd21 com_cd30 com_cd35 com_cd48 com_cd50 com_cd66 yesno

rename com_cd01 com_roadtype
rename com_cd03 com_vehicles
rename com_cd06 com_bus
rename com_cd12 com_urbancenter
rename com_cd15 com_dailymrkt
rename com_cd17 com_weeklymrkt
rename com_cd21 com_postoffice
rename com_cd23 com_publicphone
rename com_cd27r com_distprimary
rename com_cd30 com_classrooms
rename com_cd35 com_schoolelec
rename com_cd48 com_medicines
rename com_cd50 com_clinic
rename com_cd51r com_distclinic
rename com_cd66 com_bank

order $comid
sort ea_id
save "$savedata\MWI_2012_commlevel.dta", replace
********************************************************************************

** ADD POVERTY INCIDENCY INFORMATION TO HOUSEHOLD LEVEL DATA

* add poverty line
use "Q:\DataLib\Malawi\MWI_2010_IHS-III\MWI_2010_IHS-III_v01_M_v01_A_P4\Data\Stata\mwi2010_hld.dta", clear

* calculating per capital
gen pce = tocon_nd/hhsize

* identify poor and non-poor households with the national poverty line / rate, which is 37,002
gen poor = 1 if pce < 37002
replace poor = 0 if poor ==.
la var poor "Poverty status"
la def poor 0 "Non-poor" 1 "Poor"
la val poor poor
keep ori_hid wta_hh wta_pop hhsize poor
ren ori_hid hid
rename hhsize der_hhsize

sort hid
merge 1:1 hid using "$savedata\MWI_2012_household"
tab _
drop _

tab poor [iw=wta_pop] // national poverty rate is 50.7 

order hid wta_hh wta_pop der_hhsize poor 
sort hid

save "$savedata\MWI_2012_household", replace

* individual level data
use "$savedata\MWI_2012_individual.dta", clear
sort hid

merge m:1 hid using "$savedata\MWI_2012_household", keepusing(wta_hh poor)
tab _
drop _
sort hid iid
save "$savedata\MWI_2012_individual.dta", replace

********************************************************************************

** MERGE HOUSEHOLD LEVEL AND COMMUNITY LEVEL DATASETS
use "$savedata\MWI_2012_household", clear
sort ea_id
merge m:1 ea_id using "$savedata\MWI_2012_commlevel.dta"
tab _
drop ea_id _merge

compress
sort hid
save "$savedata\MWI_2012_household.dta", replace

********************************************************************************

* Extracting additional variables
* 1) Quintile
* 2) Total expenditure
* 3) Food and non-food expenditure
* 4) Expenditures for the 12 COICOP categories
* 5) Poverty line

* add poverty line
use "Q:\DataLib\Malawi\MWI_2010_IHS-III\MWI_2010_IHS-III_v01_M_v01_A_P4\Data\Stata\mwi2010_hld.dta", clear

* calculating per capital
gen pce = tocon_nd/hhsize
xtile quintile=pce [pw=wta_pop], nq(5)
la var quintile "Quintile based on per capita expenditure"
gen povline = 37002

la var povline "Poverty line based on national poverty line estimate"
keep ori_hid hid quintile povline tocon_nd focon_nd nfcon_nd 
order ori_hid hid quintile povline tocon_nd focon_nd nfcon_nd  
sort hid

save "$savedata\MWI_addition_hhlevel.dta", replace

use "Q:\DataLib\Malawi\MWI_2010_IHS-III\MWI_2010_IHS-III_v01_M_v01_A_P4\Data\Stata\mwi2010_ppp.dta", clear


merge m:1 hid using "$savedata\MWI_addition_hhlevel.dta", keepusing(ori_hid)
tab _
drop _

sort icp_seq

merge m:1 icp_seq using "Q:\KCP2009\KCP_shared_files\icp_codes.dta", keepusing(category)
tab _
drop if _==2
drop _
collapse (sum) cons_tot, by(ori_hid category)
ren ori_hid hid
ren cons_tot expcat
reshape wide expcat, i(hid) j(category)

la var expcat1101 "Food and non-alcoholic beverages"
la var expcat1102 "Alcoholic beverages, tobacco and narcotics"
la var expcat1103 "Clothing and footwear"
la var expcat1104 "Housing, water, electricity, gas and other fuels"
la var expcat1105 "Furnishings, household equipment, household maintenance"
la var expcat1106 "Health"
la var expcat1107 "Transport"
la var expcat1108 "Communication"
la var expcat1109 "Recreation and culture"
la var expcat1110 "Education"
la var expcat1111 "Restaurants and hotels"
la var expcat1112 "Miscellaneous goods and services"

sort hid
tempfile catdata
save `catdata', replace

use  "$savedata\MWI_addition_hhlevel.dta", clear
drop hid
ren ori_hid hid
merge 1:1 hid using `catdata'
tab _
drop _

sort hid
save "$savedata\MWI_addition_hhlevel.dta", replace 
